==> eiffelstudio-18.11.10.2592.tar: F_code/C2/co66.c <==
/*
 * Code for class CODE_SETS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co66.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CODE_SETS}.two_byte_code_pages */
static EIF_REFERENCE F79_2401_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOSP (2401);
#define Result RTOSR(2401)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,605,0xFF01,1014,0xFF01,1014,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 605, _OBJSIZ_7_3_0_7_0_0_0_0_);
	}
	F606_5156(RTCW(tr1), ((EIF_INTEGER_32) 20L));
	Result = (EIF_REFERENCE) tr1;
	tr1 = RTMS_EX_H("UCS-2",5,1130177330);
	tr2 = RTMS_EX_H("ucs-2",5,1669391154);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("ISO-10646-UCS-2",15,137660722);
	tr2 = RTMS_EX_H("iso-10646-ucs-2",15,932466994);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("csUnicode",9,1140938597);
	tr2 = RTMS_EX_H("csunicode",9,67227493);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-2BE",7,722937925);
	tr2 = RTMS_EX_H("ucs-2be",7,1859875173);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UNICODEBIG",10,266927431);
	tr2 = RTMS_EX_H("unicodebig",10,1691026535);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UNICODE-1-1",11,1407647281);
	tr2 = RTMS_EX_H("unicode-1-1",11,366474289);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("csUnicode11",11,1599950641);
	tr2 = RTMS_EX_H("csunicode11",11,1339907633);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-2LE",7,722940485);
	tr2 = RTMS_EX_H("ucs-2le",7,1859877733);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UNICODELITTLE",13,852373061);
	tr2 = RTMS_EX_H("unicodelittle",13,1164725349);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-16",6,1345128758);
	tr2 = RTMS_EX_H("utf-16",6,1945159990);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-16BE",8,312182853);
	tr2 = RTMS_EX_H("utf-16be",8,1456247141);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-16LE",8,312185413);
	tr2 = RTMS_EX_H("utf-16le",8,1456249701);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-2-INTERNAL",14,834453068);
	tr2 = RTMS_EX_H("ucs-2-internal",14,1377880940);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-2-SWAPPED",13,297507908);
	tr2 = RTMS_EX_H("ucs-2-swapped",13,861666404);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("JAVA",4,1245795905);
	tr2 = RTMS_EX_H("java",4,1784772193);
	F606_5202(RTCW(Result), tr1, tr2);
	RTOSE (2401);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F79_2401 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(2401,F79_2401_body,(Current));
}

/* {CODE_SETS}.four_byte_code_pages */
static EIF_REFERENCE F79_2402_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOSP (2402);
#define Result RTOSR(2402)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,605,0xFF01,1014,0xFF01,1014,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 605, _OBJSIZ_7_3_0_7_0_0_0_0_);
	}
	F606_5156(RTCW(tr1), ((EIF_INTEGER_32) 10L));
	Result = (EIF_REFERENCE) tr1;
	tr1 = RTMS_EX_H("UCS-4",5,1130177332);
	tr2 = RTMS_EX_H("ucs-4",5,1669391156);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("ISO-10646-UCS-4",15,137660724);
	tr2 = RTMS_EX_H("iso-10646-ucs-4",15,932466996);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("csUCS4",6,1626000692);
	tr2 = RTMS_EX_H("csucs4",6,17497140);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4BE",7,723068997);
	tr2 = RTMS_EX_H("ucs-4be",7,1860006245);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4LE",7,723071557);
	tr2 = RTMS_EX_H("ucs-4le",7,1860008805);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-32",6,1345129266);
	tr2 = RTMS_EX_H("utf-32",6,1945160498);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-32BE",8,345475141);
	tr2 = RTMS_EX_H("utf-32be",8,1489539429);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-32LE",8,345477701);
	tr2 = RTMS_EX_H("utf-32le",8,1489541989);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4-INTERNAL",14,968724556);
	tr2 = RTMS_EX_H("ucs-4-internal",14,1512152428);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4-SWAPPED",13,415472708);
	tr2 = RTMS_EX_H("ucs-4-swapped",13,979631204);
	F606_5202(RTCW(Result), tr1, tr2);
	RTOSE (2402);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F79_2402 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(2402,F79_2402_body,(Current));
}

/* {CODE_SETS}.little_endian_code_pages */
static EIF_REFERENCE F79_2403_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOSP (2403);
#define Result RTOSR(2403)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,605,0xFF01,1014,0xFF01,1014,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 605, _OBJSIZ_7_3_0_7_0_0_0_0_);
	}
	F606_5156(RTCW(tr1), ((EIF_INTEGER_32) 5L));
	Result = (EIF_REFERENCE) tr1;
	tr1 = RTMS_EX_H("UCS-2LE",7,722940485);
	tr2 = RTMS_EX_H("ucs-2le",7,1859877733);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UNICODELITTLE",13,852373061);
	tr2 = RTMS_EX_H("unicodelittle",13,1164725349);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-16LE",8,312185413);
	tr2 = RTMS_EX_H("utf-16le",8,1456249701);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4LE",7,723071557);
	tr2 = RTMS_EX_H("ucs-4le",7,1860008805);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-32LE",8,345477701);
	tr2 = RTMS_EX_H("utf-32le",8,1489541989);
	F606_5202(RTCW(Result), tr1, tr2);
	RTOSE (2403);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F79_2403 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(2403,F79_2403_body,(Current));
}

/* {CODE_SETS}.big_endian_code_pages */
static EIF_REFERENCE F79_2404_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOSP (2404);
#define Result RTOSR(2404)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,605,0xFF01,1014,0xFF01,1014,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 605, _OBJSIZ_7_3_0_7_0_0_0_0_);
	}
	F606_5156(RTCW(tr1), ((EIF_INTEGER_32) 5L));
	Result = (EIF_REFERENCE) tr1;
	tr1 = RTMS_EX_H("UCS-2BE",7,722937925);
	tr2 = RTMS_EX_H("ucs-2be",7,1859875173);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UNICODEBIG",10,266927431);
	tr2 = RTMS_EX_H("unicodebig",10,1691026535);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-16BE",8,312182853);
	tr2 = RTMS_EX_H("utf-16be",8,1456247141);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4BE",7,723068997);
	tr2 = RTMS_EX_H("ucs-4be",7,1860006245);
	F606_5202(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-32BE",8,345475141);
	tr2 = RTMS_EX_H("utf-32be",8,1489539429);
	F606_5202(RTCW(Result), tr1, tr2);
	RTOSE (2404);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F79_2404 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(2404,F79_2404_body,(Current));
}

void EIF_Minit66 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-23.09.10.7341.tar: F_code/C2/co66.c <==
/*
 * Code for class CODE_SETS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co66.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CODE_SETS}.two_byte_code_pages */
static EIF_REFERENCE F78_1244_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOSP (1244);
#define Result RTOSR(1244)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {671,1000,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 671, _OBJSIZ_7_4_0_7_0_0_0_0_);
	}
	F672_5663(RTCW(tr1), ((EIF_INTEGER_32) 20L));
	Result = (EIF_REFERENCE) tr1;
	tr1 = RTMS_EX_H("UCS-2",5,1130177330);
	tr2 = RTMS_EX_H("ucs-2",5,1669391154);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("ISO-10646-UCS-2",15,137660722);
	tr2 = RTMS_EX_H("iso-10646-ucs-2",15,932466994);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("csUnicode",9,1140938597);
	tr2 = RTMS_EX_H("csunicode",9,67227493);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-2BE",7,722937925);
	tr2 = RTMS_EX_H("ucs-2be",7,1859875173);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UNICODEBIG",10,266927431);
	tr2 = RTMS_EX_H("unicodebig",10,1691026535);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UNICODE-1-1",11,1407647281);
	tr2 = RTMS_EX_H("unicode-1-1",11,366474289);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("csUnicode11",11,1599950641);
	tr2 = RTMS_EX_H("csunicode11",11,1339907633);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-2LE",7,722940485);
	tr2 = RTMS_EX_H("ucs-2le",7,1859877733);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UNICODELITTLE",13,852373061);
	tr2 = RTMS_EX_H("unicodelittle",13,1164725349);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTOSCF(472,F23_472, (Current));
	tr2 = RTMS_EX_H("utf-16",6,1945159990);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTOSCF(476,F23_476, (Current));
	tr2 = RTMS_EX_H("utf-16be",8,1456247141);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTOSCF(474,F23_474, (Current));
	tr2 = RTMS_EX_H("utf-16le",8,1456249701);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-2-INTERNAL",14,834453068);
	tr2 = RTMS_EX_H("ucs-2-internal",14,1377880940);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-2-SWAPPED",13,297507908);
	tr2 = RTMS_EX_H("ucs-2-swapped",13,861666404);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("JAVA",4,1245795905);
	tr2 = RTMS_EX_H("java",4,1784772193);
	F665_5588(RTCW(Result), tr1, tr2);
	RTOSE (1244);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F78_1244 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(1244,F78_1244_body,(Current));
}

/* {CODE_SETS}.four_byte_code_pages */
static EIF_REFERENCE F78_1245_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOSP (1245);
#define Result RTOSR(1245)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {671,1000,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 671, _OBJSIZ_7_4_0_7_0_0_0_0_);
	}
	F672_5663(RTCW(tr1), ((EIF_INTEGER_32) 10L));
	Result = (EIF_REFERENCE) tr1;
	tr1 = RTMS_EX_H("UCS-4",5,1130177332);
	tr2 = RTMS_EX_H("ucs-4",5,1669391156);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("ISO-10646-UCS-4",15,137660724);
	tr2 = RTMS_EX_H("iso-10646-ucs-4",15,932466996);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("csUCS4",6,1626000692);
	tr2 = RTMS_EX_H("csucs4",6,17497140);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4BE",7,723068997);
	tr2 = RTMS_EX_H("ucs-4be",7,1860006245);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4LE",7,723071557);
	tr2 = RTMS_EX_H("ucs-4le",7,1860008805);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTOSCF(473,F23_473, (Current));
	tr2 = RTMS_EX_H("utf-32",6,1945160498);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTOSCF(477,F23_477, (Current));
	tr2 = RTMS_EX_H("utf-32be",8,1489539429);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTOSCF(475,F23_475, (Current));
	tr2 = RTMS_EX_H("utf-32le",8,1489541989);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4-INTERNAL",14,968724556);
	tr2 = RTMS_EX_H("ucs-4-internal",14,1512152428);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4-SWAPPED",13,415472708);
	tr2 = RTMS_EX_H("ucs-4-swapped",13,979631204);
	F665_5588(RTCW(Result), tr1, tr2);
	RTOSE (1245);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F78_1245 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(1245,F78_1245_body,(Current));
}

/* {CODE_SETS}.little_endian_code_pages */
static EIF_REFERENCE F78_1246_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOSP (1246);
#define Result RTOSR(1246)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {671,1000,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 671, _OBJSIZ_7_4_0_7_0_0_0_0_);
	}
	F672_5663(RTCW(tr1), ((EIF_INTEGER_32) 5L));
	Result = (EIF_REFERENCE) tr1;
	tr1 = RTMS_EX_H("UCS-2LE",7,722940485);
	tr2 = RTMS_EX_H("ucs-2le",7,1859877733);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UNICODELITTLE",13,852373061);
	tr2 = RTMS_EX_H("unicodelittle",13,1164725349);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTOSCF(474,F23_474, (Current));
	tr2 = RTMS_EX_H("utf-16le",8,1456249701);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4LE",7,723071557);
	tr2 = RTMS_EX_H("ucs-4le",7,1860008805);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTOSCF(475,F23_475, (Current));
	tr2 = RTMS_EX_H("utf-32le",8,1489541989);
	F665_5588(RTCW(Result), tr1, tr2);
	RTOSE (1246);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F78_1246 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(1246,F78_1246_body,(Current));
}

/* {CODE_SETS}.big_endian_code_pages */
static EIF_REFERENCE F78_1247_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOSP (1247);
#define Result RTOSR(1247)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {671,1000,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 671, _OBJSIZ_7_4_0_7_0_0_0_0_);
	}
	F672_5663(RTCW(tr1), ((EIF_INTEGER_32) 5L));
	Result = (EIF_REFERENCE) tr1;
	tr1 = RTMS_EX_H("UCS-2BE",7,722937925);
	tr2 = RTMS_EX_H("ucs-2be",7,1859875173);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UNICODEBIG",10,266927431);
	tr2 = RTMS_EX_H("unicodebig",10,1691026535);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTOSCF(476,F23_476, (Current));
	tr2 = RTMS_EX_H("utf-16be",8,1456247141);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4BE",7,723068997);
	tr2 = RTMS_EX_H("ucs-4be",7,1860006245);
	F665_5588(RTCW(Result), tr1, tr2);
	tr1 = RTOSCF(477,F23_477, (Current));
	tr2 = RTMS_EX_H("utf-32be",8,1489539429);
	F665_5588(RTCW(Result), tr1, tr2);
	RTOSE (1247);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F78_1247 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(1247,F78_1247_body,(Current));
}

void EIF_Minit66 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
